==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-numeric-y-axis.js <==
import * as tslib_1 from "tslib";
import { IgrStraightNumericAxisBase } from "./igr-straight-numeric-axis-base";
import { NumericYAxis } from "./NumericYAxis";
/**
 * Represents a IgxDataChartComponent numeric Y axis.
*
* The `IgxNumericYAxisComponent` treats the data as continuously varying numerical data items. Labels on this axis are placed along the Y-axis. Location of labels varies according to the value in a data column that is mapped using the `YMemberPath` property for Scatter Series or `ValueMemberPath` property for Category Series.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-category-x-axis
*         label="label"
*         #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*         #yAxis>
*     </igx-numeric-y-axis>
*     <igx-column-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value">
*     </igx-column-series>
* </igx-data-chart>
* ```
*/
var IgrNumericYAxis = /** @class */ (function (_super) {
    tslib_1.__extends(IgrNumericYAxis, _super);
    function IgrNumericYAxis(props) {
        return _super.call(this, props) || this;
    }
    IgrNumericYAxis.prototype.createImplementation = function () {
        return new NumericYAxis();
    };
    Object.defineProperty(IgrNumericYAxis.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrNumericYAxis.prototype, "isVertical", {
        /**
         * Gets if the current axis is of vertical axis
        */
        get: function () {
            return this.i.ce;
        },
        enumerable: true,
        configurable: true
    });
    IgrNumericYAxis.prototype.scrollRangeIntoView = function (minimum, maximum) {
        this.i.lo(minimum, maximum);
    };
    return IgrNumericYAxis;
}(IgrStraightNumericAxisBase));
export { IgrNumericYAxis };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-numeric-y-axis.js <==
import * as tslib_1 from "tslib";
import { IgrStraightNumericAxisBase } from "./igr-straight-numeric-axis-base";
import { NumericYAxis } from "./NumericYAxis";
/**
 * Represents a IgxDataChartComponent numeric Y axis.
*
* The `IgrNumericYAxis` treats the data as continuously varying numerical data items. Labels on this axis are placed along the Y-axis. Location of labels varies according to the value in a data column that is mapped using the `YMemberPath` property for Scatter Series or `ValueMemberPath` property for Category Series.
*/
var IgrNumericYAxis = /** @class */ (function (_super) {
    tslib_1.__extends(IgrNumericYAxis, _super);
    function IgrNumericYAxis(props) {
        return _super.call(this, props) || this;
    }
    IgrNumericYAxis.prototype.createImplementation = function () {
        return new NumericYAxis();
    };
    Object.defineProperty(IgrNumericYAxis.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrNumericYAxis.prototype, "isVertical", {
        /**
         * Gets if the current axis is of vertical axis
        */
        get: function () {
            return this.i.ce;
        },
        enumerable: true,
        configurable: true
    });
    IgrNumericYAxis.prototype.scrollRangeIntoView = function (minimum, maximum) {
        this.i.lo(minimum, maximum);
    };
    return IgrNumericYAxis;
}(IgrStraightNumericAxisBase));
export { IgrNumericYAxis };
